Changelog
=========

1.1.0 (2021-07-28)
------------------
- Added ``--source-id-type`` option to avoid "StringToNumberOp could not correctly
  convert string" exception with some algorithms (see https://github.com/google/automl/issues/307).

1.0.0 (2021-05-20)
------------------

- Initial release after separation from wai.annotations main repo.
